@@ -14,7 +14,7 @@ import wavesynth
 m = opt.testFunction(wavesynth.printTrack)
 
 arpeggio.arpeggio(wavesynth.C4, 0.5)
-m.case().expectOutputLines(
+m.case().checkPrintedLines(
     "a 0.5s keyboard note at C4",
     "and a 0.5s keyboard note at E4",
     "and a 0.5s keyboard note at G4",
@@ -26,7 +26,7 @@ m.case().expectOutputLines(
 wavesynth.eraseTrack()
 
 arpeggio.arpeggio(wavesynth.B3, 0.3)
-m.case().expectOutputLines(
+m.case().checkPrintedLines(
     "a 0.3s keyboard note at B3",
     "and a 0.3s keyboard note at Eb4",
     "and a 0.3s keyboard note at Gb4",
