@@ -153,10 +153,10 @@ printTrack()
 import optimism as opt
 
 # Use captureOutput to set up a test case for the printTrack output
-opt.captureOutput()
-opt.testCase(printTrack())
-opt.expectOutputContains("a 0.2s keyboard note at C4")
-opt.expectOutputContains("and a 0.3s keyboard note at D4")
+m = opt.testFunction(printTrack)
+c = m.case()
+c.checkPrintedFragment("a 0.2s keyboard note at C4")
+c.checkPrintedFragment("and a 0.3s keyboard note at D4")
 # Note: our expectations don't constrain the volume level, but they could
 """
     ]
