@@ -5,6 +5,7 @@ test_eval.py
 """
 
 import os
+import sys
 import json
 import pathlib
 import subprocess
@@ -138,12 +139,25 @@ def in_evaldir():
     Sets the current directory to the testarea evaluation directory.
     Yields that directory as a pathlib.Path.
     """
-    with importlib_resources.path("potluck", "testarea") as testarea:
-        evaldir = testarea / "test_course" / "fall2021"
-        old_dir = os.getcwd()
-        os.chdir(evaldir)
-        yield evaldir
-        os.chdir(old_dir)
+    if (
+        hasattr(importlib_resources, "files")
+    and hasattr(importlib_resources, "as_file")
+    ):
+        # For newer versions of importlib_resources
+        taPath = importlib_resources.files("potluck").joinpath("testarea")
+        with importlib_resources.as_file(taPath) as testarea:
+            evaldir = testarea / "test_course" / "fall2021"
+            old_dir = os.getcwd()
+            os.chdir(evaldir)
+            yield evaldir
+            os.chdir(old_dir)
+    else:
+        with importlib_resources.path("potluck", "testarea") as testarea:
+            evaldir = testarea / "test_course" / "fall2021"
+            old_dir = os.getcwd()
+            os.chdir(evaldir)
+            yield evaldir
+            os.chdir(old_dir)
 
 
 @pytest.fixture
